===========
bruges is a
===========

.. image:: http://agile.geosci.ai/bruges.png

In other words, it's just a load of functions that implement important equations in (mostly seismic) geophysics, from Aki-Richards to Zoeppritz.